<a href="https://www.islas.org.mx/"><img src="https://www.islas.org.mx/img/logo.svg" align="right" width="256" /></a>
# Population trend
[![codecov](https://codecov.io/gh/IslasGECI/population_trend/graph/badge.svg?token=wyxnwZypMA)](https://codecov.io/gh/IslasGECI/population_trend)
![example branch
parameter](https://github.com/IslasGECI/population_trend/actions/workflows/actions.yml/badge.svg)
![licencia](https://img.shields.io/github/license/IslasGECI/population_trend)
![languages](https://img.shields.io/github/languages/top/IslasGECI/population_trend)
![commits](https://img.shields.io/github/commit-activity/y/IslasGECI/population_trend)
![GitHub contributors](https://img.shields.io/github/contributors/IslasGECI/population_trend)

Este repo lo usamos en lambdas y cormorant.

Tiene la clase para graficas `Plotter_Population_Trend_Model`.
